@@ -14,7 +14,7 @@ import pyautogui
 
 from scipy import interpolate
 
-from mouse import Mouse
+from .mouse import Mouse
 
 
 name = 'pyHM'
